@@ -84,7 +84,7 @@ class Application(Gtk.Application):
             self.add_arguments()
         else:
             ErrorDialog(
-                "Your Linux distribution is too old, Lutris won't function properly"
+                "Your Linux distribution is too old. Lutris won't function properly."
             )
 
     def add_arguments(self):
@@ -342,6 +342,9 @@ class Application(Gtk.Application):
         game.load_config()  # Reload the config before launching it.
         game.play()
 
+        if settings.read_setting("hide_client_on_game_start") == "True":
+            self.window.hide()  # Hide launcher window
+
     def get_game_by_id(self, game_id):
         for i in range(self.running_games.get_n_items()):
             game = self.running_games.get_item(i)
@@ -356,11 +359,18 @@ class Application(Gtk.Application):
 
     def on_game_stop(self, game):
         """Callback to remove the game from the running games"""
+        game.disconnect_by_func(self.on_game_stop)
         game_index = self.get_game_index(game.id)
         if game_index is not None:
             self.running_games.remove(game_index)
         game.emit("game-stopped", game.id)
 
+        if settings.read_setting("hide_client_on_game_start") == "True":
+            self.window.show()  # Show launcher window
+        elif not self.window.is_visible():
+            if self.running_games.get_n_items() == 0:
+                self.quit()
+
     @staticmethod
     def get_lutris_action(url):
         installer_info = {"game_slug": None, "revision": None, "action": None}
