@@ -1,5 +1,6 @@
 """Shared config dialog stuff"""
 # pylint: disable=no-member,not-an-iterable
+import importlib
 import os
 from gi.repository import Gtk, Pango, GLib
 from lutris.game import Game
@@ -104,6 +105,8 @@ class GameDialogCommon:
         )
         prefs_box.pack_start(cache_help_label, False, False, 6)
 
+        prefs_box.pack_start(self._get_hide_on_game_launch_box(), False, False, 6)
+
         info_sw = self.build_scrolled_window(prefs_box)
         self._add_notebook_tab(info_sw, "Lutris preferences")
 
@@ -121,6 +124,19 @@ class GameDialogCommon:
         box.pack_start(path_chooser, True, True, 0)
         return box
 
+    def _get_hide_on_game_launch_box(self):
+        box = Gtk.Box(spacing=12, margin_right=12, margin_left=12)
+        checkbox = Gtk.CheckButton(label="Minimize client when a game is launched")
+        if settings.read_setting("hide_client_on_game_start") == "True":
+            checkbox.set_active(True)
+        checkbox.connect("toggled", self._on_hide_client_change)
+        box.pack_start(checkbox, True, True, 0)
+        return box
+
+    def _on_hide_client_change(self, widget):
+        """Save setting for hiding the game on game launch"""
+        settings.write_setting("hide_client_on_game_start", widget.get_active())
+
     def _on_cache_path_set(self, entry):
         if self.timer_id:
             GLib.source_remove(self.timer_id)
@@ -338,9 +354,8 @@ class GameDialogCommon:
 
         # Advanced settings checkbox
         checkbox = Gtk.CheckButton(label="Show advanced options")
-        value = settings.read_setting("show_advanced_options")
-        if value == "True":
-            checkbox.set_active(value)
+        if settings.read_setting("show_advanced_options") == "True":
+            checkbox.set_active(True)
         checkbox.connect("toggled", self.on_show_advanced_options_toggled)
         self.action_area.pack_start(checkbox, False, False, 5)
 
@@ -441,6 +456,25 @@ class GameDialogCommon:
         ):
             ErrorDialog("Steam AppId not provided")
             return False
+        invalid_fields = []
+        runner_module = importlib.import_module("lutris.runners." + self.runner_name)
+        runner_class = getattr(runner_module, self.runner_name)
+        runner_instance = runner_class()
+        for config in ["game", "runner"]:
+            for k, v in getattr(self.lutris_config, config + "_config").items():
+                option = runner_instance.find_option(config + "_options", k)
+                if option is None:
+                    continue
+                validator = option.get("validator")
+                if validator is not None:
+                    try:
+                        res = validator(v)
+                        logger.debug("{} validated successfully: {}".format(k, res))
+                    except Exception:
+                        invalid_fields.append(option.get("label"))
+        if invalid_fields:
+            ErrorDialog("The following fields have invalid values: " + ", ".join(invalid_fields))
+            return False
         return True
 
     def on_save(self, _button):
