@@ -1,3 +1,4 @@
+"""Window used for game installers"""
 import os
 import time
 import webbrowser
@@ -13,7 +14,7 @@ from lutris.gui.dialogs import (
     NoInstallerDialog, DirectoryDialog, InstallerSourceDialog, QuestionDialog
 )
 from lutris.gui.widgets.download_progress import DownloadProgressBox
-from lutris.gui.widgets.common import FileChooserEntry
+from lutris.gui.widgets.common import FileChooserEntry, InstallerLabel
 from lutris.gui.widgets.installer import InstallerPicker
 from lutris.gui.widgets.log_text_view import LogTextView
 from lutris.gui.widgets.window import BaseApplicationWindow
@@ -49,10 +50,10 @@ class InstallerWindow(BaseApplicationWindow):
         self.log_buffer = None
         self.log_textview = None
 
-        self.title_label = Gtk.Label()
+        self.title_label = InstallerLabel()
         self.vbox.add(self.title_label)
 
-        self.status_label = Gtk.Label()
+        self.status_label = InstallerLabel()
         self.status_label.set_max_width_chars(80)
         self.status_label.set_property("wrap", True)
         self.status_label.set_selectable(True)
@@ -71,7 +72,7 @@ class InstallerWindow(BaseApplicationWindow):
         self.vbox.pack_start(action_buttons_alignment, False, True, 0)
 
         self.cancel_button = Gtk.Button.new_with_mnemonic("C_ancel")
-        self.cancel_button.set_tooltip_text("Abort and revert the " "installation")
+        self.cancel_button.set_tooltip_text("Abort and revert the installation")
         self.cancel_button.connect("clicked", self.cancel_installation)
         self.action_buttons.add(self.cancel_button)
 
@@ -79,12 +80,20 @@ class InstallerWindow(BaseApplicationWindow):
         self.source_button = self.add_button("_View source", self.on_source_clicked)
         self.install_button = self.add_button("_Install", self.on_install_clicked)
         self.continue_button = self.add_button("_Continue")
-        self.play_button = self.add_button("_Launch game", self.launch_game)
+        self.play_button = self.add_button("_Launch", self.launch_game)
         self.close_button = self.add_button("_Close", self.on_destroy)
 
         self.continue_handler = None
 
-        self.get_scripts()
+        # check if installer is local or online
+        if system.path_exists(self.installer_file):
+            self.get_scripts(local_script=True)
+        else:
+            self.title_label.set_markup("Waiting for response from %s" % (settings.SITE_URL))
+            self.add_spinner()
+            self.widget_box.show()
+            self.title_label.show()
+            self.get_scripts(local_script=False)
 
         self.present()
 
@@ -95,9 +104,8 @@ class InstallerWindow(BaseApplicationWindow):
         self.action_buttons.add(button)
         return button
 
-    def get_scripts(self):
-        if system.path_exists(self.installer_file):
-            # local script
+    def get_scripts(self, local_script=False):
+        if local_script:
             self.on_scripts_obtained(interpreter.read_script(self.installer_file))
         else:
             jobs.AsyncCall(
@@ -115,6 +123,7 @@ class InstallerWindow(BaseApplicationWindow):
 
         if not isinstance(scripts, list):
             scripts = [scripts]
+        self.clean_widgets()
         self.scripts = scripts
         self.show_all()
         self.close_button.hide()
@@ -192,7 +201,7 @@ class InstallerWindow(BaseApplicationWindow):
         except MissingGameDependency as ex:
             dlg = QuestionDialog(
                 {
-                    "question": "This game requires %s, do you want to install it?" % ex.slug,
+                    "question": "This game requires %s. Do you want to install it?" % ex.slug,
                     "title": "Missing dependency",
                 }
             )
@@ -275,9 +284,13 @@ class InstallerWindow(BaseApplicationWindow):
         if action == "file":
             title = "Select file"
             action = Gtk.FileChooserAction.OPEN
+            enable_warnings = False
         elif action == "folder":
             title = "Select folder"
             action = Gtk.FileChooserAction.SELECT_FOLDER
+            enable_warnings = True
+        else:
+            raise ValueError("Invalid action %s", action)
 
         if self.location_entry:
             self.location_entry.destroy()
@@ -285,8 +298,8 @@ class InstallerWindow(BaseApplicationWindow):
             title,
             action,
             path=default_path,
-            warn_if_non_empty=True,
-            warn_if_ntfs=True
+            warn_if_non_empty=enable_warnings,
+            warn_if_ntfs=enable_warnings
         )
         self.location_entry.entry.connect("changed", callback_on_changed, action)
         self.widget_box.pack_start(self.location_entry, False, False, 0)
@@ -331,10 +344,9 @@ class InstallerWindow(BaseApplicationWindow):
         """Ask the user to do insert a CD-ROM."""
         time.sleep(0.3)
         self.clean_widgets()
-        label = Gtk.Label(label=message)
-        label.set_use_markup(True)
-        self.widget_box.add(label)
+        label = InstallerLabel(message)
         label.show()
+        self.widget_box.add(label)
 
         buttons_box = Gtk.Box()
         buttons_box.show()
@@ -422,7 +434,6 @@ class InstallerWindow(BaseApplicationWindow):
         self.play_button.show()
         self.close_button.grab_focus()
         self.close_button.show()
-
         if not self.is_active():
             self.set_urgency_hint(True)  # Blink in taskbar
             self.connect("focus-in-event", self.on_window_focus)
@@ -470,15 +481,22 @@ class InstallerWindow(BaseApplicationWindow):
 
     def cancel_installation(self, widget=None):
         """Ask a confirmation before cancelling the install"""
+        remove_checkbox = Gtk.CheckButton.new_with_label("Remove game files")
+        if self.interpreter:
+            remove_checkbox.set_active(self.interpreter.game_dir_created)
+            remove_checkbox.show()
         confirm_cancel_dialog = QuestionDialog(
             {
                 "question": "Are you sure you want to cancel the installation?",
                 "title": "Cancel installation?",
+                "widgets": [remove_checkbox]
             }
         )
         if confirm_cancel_dialog.result != Gtk.ResponseType.YES:
+            logger.debug("User cancelled installation")
             return True
         if self.interpreter:
+            self.interpreter.game_dir_created = remove_checkbox.get_active()
             self.interpreter.revert()
             self.interpreter.cleanup()
         self.destroy()
@@ -499,11 +517,8 @@ class InstallerWindow(BaseApplicationWindow):
 
     def set_message(self, message):
         """Display a message."""
-        label = Gtk.Label()
+        label = InstallerLabel()
         label.set_markup("<b>%s</b>" % add_url_tags(message))
-        label.set_max_width_chars(80)
-        label.set_property("wrap", True)
-        label.set_alignment(0, 0)
         label.show()
         self.widget_box.pack_start(label, False, False, 18)
 
