@@ -17,6 +17,7 @@ from lutris.util.jobs import AsyncCall
 
 from lutris.util import http
 from lutris.util import datapath
+
 # from lutris.util.steam.watcher import SteamWatcher
 
 from lutris.services import get_services_synced_at_startup, steam
@@ -73,6 +74,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
         super().__init__(
             default_width=width,
             default_height=height,
+            window_position=Gtk.WindowPosition.NONE,
             icon_name="lutris",
             application=application,
             **kwargs
@@ -102,9 +104,10 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
         GObject.add_emission_hook(Game, "game-updated", self.on_game_updated)
         GObject.add_emission_hook(Game, "game-removed", self.on_game_updated)
-        GObject.add_emission_hook(GenericPanel,
-                                  "running-game-selected",
-                                  self.game_selection_changed)
+        GObject.add_emission_hook(Game, "game-started", self.on_game_started)
+        GObject.add_emission_hook(
+            GenericPanel, "running-game-selected", self.game_selection_changed
+        )
         self.connect("delete-event", self.on_window_delete)
         if self.maximized:
             self.maximize()
@@ -141,7 +144,6 @@ class LutrisWindow(Gtk.ApplicationWindow):
         self.panel_revealer = Gtk.Revealer(visible=True)
         self.panel_revealer.set_transition_duration(300)
         self.panel_revealer.set_transition_type(Gtk.RevealerTransitionType.SLIDE_LEFT)
-        self.panel_revealer.set_reveal_child(True)
         self.panel_revealer.add(self.game_scrolled)
 
         self.main_box.pack_end(self.panel_revealer, False, False, 0)
@@ -152,9 +154,11 @@ class LutrisWindow(Gtk.ApplicationWindow):
         # Contextual menu
         self.view.contextual_menu = ContextualMenu(self.game_actions.get_game_actions())
 
-        # Sidebar
-        self.sidebar_revealer.set_reveal_child(self.sidebar_visible)
+        # Left/Right Sidebar visibility
+        self.sidebar_revealer.set_reveal_child(self.left_side_panel_visible)
         self.sidebar_revealer.set_transition_duration(300)
+        self.panel_revealer.set_reveal_child(self.right_side_panel_visible)
+        self.panel_revealer.set_transition_duration(300)
         self.update_runtime()
 
         # Connect account and/or sync
@@ -215,12 +219,18 @@ class LutrisWindow(Gtk.ApplicationWindow):
             "use-dark-theme": Action(
                 self.on_dark_theme_state_change, type="b", default=self.use_dark_theme
             ),
-            "show-side-bar": Action(
-                self.on_sidebar_state_change,
+            "show-left-side-panel": Action(
+                self.on_left_side_panel_state_change,
                 type="b",
-                default=self.sidebar_visible,
+                default=self.left_side_panel_visible,
                 accel="F9",
             ),
+            "show-right-side-panel": Action(
+                self.on_right_side_panel_state_change,
+                type="b",
+                default=self.right_side_panel_visible,
+                accel="F10",
+            ),
             "open-forums": Action(lambda *x: open_uri("https://forums.lutris.net/")),
             "open-discord": Action(lambda *x: open_uri("https://discord.gg/Pnt5CuY")),
             "donate": Action(lambda *x: open_uri("https://lutris.net/donate")),
@@ -255,10 +265,25 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     @property
     def filter_installed(self):
-        return settings.read_setting("filter_installed") == "true"
+        return settings.read_setting("filter_installed").lower() == "true"
+
+    @property
+    def left_side_panel_visible(self):
+        show_left_panel = (
+            settings.read_setting("left_side_panel_visible").lower() != "false"
+        )
+        return show_left_panel or self.sidebar_visible
+
+    @property
+    def right_side_panel_visible(self):
+        show_right_panel = (
+            settings.read_setting("right_side_panel_visible").lower() != "false"
+        )
+        return show_right_panel or self.sidebar_visible
 
     @property
     def sidebar_visible(self):
+        """Deprecated: For compability only"""
         return settings.read_setting("sidebar_visible") in [
             "true",
             None,
@@ -271,7 +296,10 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     @property
     def show_installed_first(self):
-        return settings.read_setting("show_installed_first") == "true"
+        return (
+            settings.read_setting("show_installed_first", default="false").lower()
+            == "true"
+        )
 
     @property
     def view_sorting(self):
@@ -279,7 +307,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     @property
     def view_sorting_ascending(self):
-        return settings.read_setting("view_sorting_ascending") != "false"
+        return settings.read_setting("view_sorting_ascending").lower() != "false"
 
     def get_store(self, games=None):
         """Return an instance of GameStore"""
@@ -297,6 +325,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     def sync_services(self):
         """Sync local lutris library with current Steam games and desktop games"""
+
         def full_sync(syncer_cls):
             syncer = syncer_cls()
             games = syncer.load()
@@ -355,7 +384,9 @@ class LutrisWindow(Gtk.ApplicationWindow):
     def set_dark_theme(self):
         """Enables or disbales dark theme"""
         gtksettings = Gtk.Settings.get_default()
-        gtksettings.set_property("gtk-application-prefer-dark-theme", self.use_dark_theme)
+        gtksettings.set_property(
+            "gtk-application-prefer-dark-theme", self.use_dark_theme
+        )
 
     def get_view(self, view_type):
         """Return the appropriate widget for the current view"""
@@ -458,7 +489,9 @@ class LutrisWindow(Gtk.ApplicationWindow):
         self.set_show_installed_state(self.filter_installed)
         self.view.show_all()
 
-        self.zoom_adjustment.props.value = list(IMAGE_SIZES.keys()).index(self.icon_type)
+        self.zoom_adjustment.props.value = list(IMAGE_SIZES.keys()).index(
+            self.icon_type
+        )
 
         self.set_viewtype_icon(view_type)
         settings.write_setting("view_type", view_type)
@@ -466,7 +499,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
     def set_viewtype_icon(self, view_type):
         self.viewtype_icon.set_from_icon_name(
             "view-%s-symbolic" % ("list" if view_type == "grid" else "grid"),
-            Gtk.IconSize.BUTTON
+            Gtk.IconSize.BUTTON,
         )
 
     def sync_library(self):
@@ -508,7 +541,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
     def on_dark_theme_state_change(self, action, value):
         """Callback for theme switching action"""
         action.set_state(value)
-        settings.write_setting("dark_theme", "true" if value.get_boolean() else "false")
+        settings.write_setting("dark_theme", value.get_boolean())
         self.set_dark_theme()
 
     @GtkTemplate.Callback
@@ -531,19 +564,14 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.application.launch(game)
         else:
             InstallerWindow(
-                parent=self,
-                game_slug=game.slug,
-                application=self.application,
+                parent=self, game_slug=game.slug, application=self.application,
             )
 
     @GtkTemplate.Callback
     def on_disconnect(self, *_args):
         """Callback from user disconnect"""
         dlg = dialogs.QuestionDialog(
-            {
-                "question": "Do you want to log out from Lutris?",
-                "title": "Log out?",
-            }
+            {"question": "Do you want to log out from Lutris?", "title": "Log out?", }
         )
         if dlg.result != Gtk.ResponseType.YES:
             return
@@ -575,15 +603,8 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     def on_window_delete(self, *_args):
         if self.application.running_games.get_n_items():
-            dlg = dialogs.QuestionDialog(
-                {
-                    "question": ("Some games are still running, "
-                                 "are you sure you want to quit Lutris?"),
-                    "title": "Quit Lutris?",
-                }
-            )
-            if dlg.result != Gtk.ResponseType.YES:
-                return True
+            self.hide()
+            return True
 
     @GtkTemplate.Callback
     def on_destroy(self, *_args):
@@ -622,7 +643,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     def set_show_installed_first_state(self, show_installed_first):
         """Shows the installed games first in the view"""
-        settings.write_setting("show_installed_first", "true" if show_installed_first else "false")
+        settings.write_setting("show_installed_first", bool(show_installed_first))
         self.game_store.sort_view(show_installed_first)
         self.game_store.modelfilter.refilter()
 
@@ -633,7 +654,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     def set_show_installed_state(self, filter_installed):
         """Shows or hide uninstalled games"""
-        settings.write_setting("filter_installed", "true" if filter_installed else "false")
+        settings.write_setting("filter_installed", bool(filter_installed))
         self.game_store.filter_installed = filter_installed
         self.invalidate_game_filter()
 
@@ -669,8 +690,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.search_mode = "website"
             self.search_entry.set_placeholder_text("Search Lutris.net")
             self.search_entry.set_icon_from_icon_name(
-                Gtk.EntryIconPosition.PRIMARY,
-                "folder-download-symbolic"
+                Gtk.EntryIconPosition.PRIMARY, "folder-download-symbolic"
             )
             self.game_store.search_mode = True
             self.search_games(self.search_terms)
@@ -678,8 +698,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.search_mode = "local"
             self.search_entry.set_placeholder_text("Filter the list of games")
             self.search_entry.set_icon_from_icon_name(
-                Gtk.EntryIconPosition.PRIMARY,
-                "system-search-symbolic"
+                Gtk.EntryIconPosition.PRIMARY, "system-search-symbolic"
             )
             self.search_games("")
 
@@ -693,9 +712,16 @@ class LutrisWindow(Gtk.ApplicationWindow):
         logger.error("%s crashed", game)
         dialogs.ErrorDialog(error, parent=self)
 
+    def on_game_started(self, game):
+        self.game_panel.refresh()
+        return True
+
     def on_game_updated(self, game):
         """Callback to refresh the view when a game is updated"""
         logger.debug("Updating game %s", game)
+        if not game.is_installed:
+            game = Game(game_id=game.id)
+            self.game_selection_changed(None, None)
         game.load_config()
         try:
             self.game_store.update_game_by_id(game.id)
@@ -703,7 +729,8 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.game_store.add_game_by_id(game.id)
 
         self.view.set_selected_game(game.id)
-        self.game_selection_changed(None, game)
+        if game.is_installed:
+            self.game_selection_changed(None, game)
         return True
 
     def on_search_games_fire(self, value):
@@ -737,6 +764,9 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.game_actions.set_game(game=game)
             self.game_panel = GamePanel(self.game_actions)
             self.game_panel.connect("panel-closed", self.on_panel_closed)
+            self.view.contextual_menu.connect(
+                "shortcut-edited", self.game_panel.on_shortcut_edited
+            )
         self.game_scrolled.add(self.game_panel)
         return True
 
@@ -794,17 +824,35 @@ class LutrisWindow(Gtk.ApplicationWindow):
         self.actions["view-sorting"].set_state(GLib.Variant.new_string(key))
         settings.write_setting("view_sorting", key)
 
-        self.actions["view-sorting-ascending"].set_state(GLib.Variant.new_boolean(ascending))
-        settings.write_setting("view_sorting_ascending", "true" if ascending else "false")
+        self.actions["view-sorting-ascending"].set_state(
+            GLib.Variant.new_boolean(ascending)
+        )
+        settings.write_setting("view_sorting_ascending", bool(ascending))
 
-    def on_sidebar_state_change(self, action, value):
-        """Callback to handle siderbar toggle"""
+    def on_left_side_panel_state_change(self, action, value):
+        """Callback to handle left side panel toggle"""
         action.set_state(value)
-        sidebar_visible = value.get_boolean()
-        settings.write_setting("sidebar_visible", "true" if sidebar_visible else "false")
-        self.sidebar_revealer.set_reveal_child(sidebar_visible)
-        self.panel_revealer.set_reveal_child(sidebar_visible)
-        self.game_scrolled.set_visible(sidebar_visible)
+        left_side_panel_visible = value.get_boolean()
+        settings.write_setting("left_side_panel_visible", bool(left_side_panel_visible))
+        self.sidebar_revealer.set_reveal_child(left_side_panel_visible)
+        # Retrocompatibility with sidebar_visible :
+        # if we change the new attribute, we must set the old one to false
+        if self.sidebar_visible:
+            settings.write_setting("sidebar_visible", "false")
+
+    def on_right_side_panel_state_change(self, action, value):
+        """Callback to handle right side panel toggle"""
+        action.set_state(value)
+        right_side_panel_visible = value.get_boolean()
+        settings.write_setting(
+            "right_side_panel_visible", bool(right_side_panel_visible)
+        )
+        self.panel_revealer.set_reveal_child(right_side_panel_visible)
+        self.game_scrolled.set_visible(right_side_panel_visible)
+        # Retrocompatibility with sidebar_visible :
+        # if we change the new attribute, we must set the old one to false
+        if self.sidebar_visible:
+            settings.write_setting("sidebar_visible", "false")
 
     def on_sidebar_changed(self, widget):
         row = widget.get_selected_row()
@@ -824,8 +872,12 @@ class LutrisWindow(Gtk.ApplicationWindow):
         self.invalidate_game_filter()
 
     def show_invalid_credential_warning(self):
-        dialogs.ErrorDialog("Could not connect to your Lutris account, please sign-in again.")
+        dialogs.ErrorDialog(
+            "Could not connect to your Lutris account. Please sign in again."
+        )
 
     def show_library_sync_error(self):
-        dialogs.ErrorDialog("Failed to retrieve game library, "
-                            "there might be some problems contacting lutris.net")
+        dialogs.ErrorDialog(
+            "Failed to retrieve game library. "
+            "There might be some problems contacting lutris.net"
+        )
