@@ -36,13 +36,18 @@ class GamePanel(GenericPanel):
         self.buttons = self.get_buttons()
         self.place_buttons(145)
 
+    def refresh(self):
+        self.place_content()
+
     @property
     def background_id(self):
         return self.game.slug
 
     def get_close_button(self):
         """Return the close button"""
-        button = Gtk.Button.new_from_icon_name("window-close-symbolic", Gtk.IconSize.MENU)
+        button = Gtk.Button.new_from_icon_name(
+            "window-close-symbolic", Gtk.IconSize.MENU
+        )
         button.set_tooltip_text("Close")
         button.set_size_request(32, 32)
         button.connect("clicked", self.on_close)
@@ -58,7 +63,9 @@ class GamePanel(GenericPanel):
     def get_title_label(self):
         """Return the label with the game's title"""
         title_label = Gtk.Label()
-        title_label.set_markup("<span font_desc='16'>%s</span>" % gtk_safe(self.game.name))
+        title_label.set_markup(
+            "<span font_desc='16'>%s</span>" % gtk_safe(self.game.name)
+        )
         title_label.set_ellipsize(Pango.EllipsizeMode.END)
         title_label.set_size_request(226, -1)
         title_label.set_alignment(0, 0.5)
@@ -69,7 +76,8 @@ class GamePanel(GenericPanel):
     def get_runner_label(self):
         """Return the label containing the runner info"""
         runner_icon = Gtk.Image.new_from_icon_name(
-            self.game.runner.name.lower().replace(" ", "") + "-symbolic", Gtk.IconSize.MENU
+            self.game.runner.name.lower().replace(" ", "") + "-symbolic",
+            Gtk.IconSize.MENU,
         )
         runner_icon.show()
         runner_label = Gtk.Label()
@@ -85,7 +93,9 @@ class GamePanel(GenericPanel):
         """Return the label containing the playtime info"""
         playtime_label = Gtk.Label()
         playtime_label.show()
-        playtime_label.set_markup("Time played: <b>%s</b>" % self.game.formatted_playtime)
+        playtime_label.set_markup(
+            "Time played: <b>%s</b>" % self.game.formatted_playtime
+        )
         return playtime_label
 
     def get_last_played_label(self):
@@ -93,7 +103,9 @@ class GamePanel(GenericPanel):
         last_played_label = Gtk.Label()
         last_played_label.show()
         lastplayed = datetime.fromtimestamp(self.game.lastplayed)
-        last_played_label.set_markup("Last played: <b>%s</b>" % lastplayed.strftime("%x"))
+        last_played_label.set_markup(
+            "Last played: <b>%s</b>" % lastplayed.strftime("%x")
+        )
         return last_played_label
 
     def get_runner_entries(self, game):
@@ -105,7 +117,6 @@ class GamePanel(GenericPanel):
 
     def get_buttons(self):
         displayed = self.game_actions.get_displayed_entries()
-        disabled_entries = self.game_actions.get_disabled_entries()
         icon_map = {
             # "stop": "media-playback-stop-symbolic",
             # "play": "media-playback-start-symbolic",
@@ -129,16 +140,23 @@ class GamePanel(GenericPanel):
                     button.set_size_request(146, 42)
                 else:
                     button = get_link_button(label)
-            button.connect("clicked", callback)
 
             if displayed.get(action_id):
                 button.show()
             else:
                 button.hide()
-            if disabled_entries.get(action_id):
-                button.set_sensitive(False)
             buttons[action_id] = button
 
+            if action_id in (
+                "desktop-shortcut",
+                "rm-desktop-shortcut",
+                "menu-shortcut",
+                "rm-menu-shortcut",
+            ):
+                button.connect("clicked", self.on_shortcut_edited, action_id)
+
+            button.connect("clicked", callback)
+
         if self.game.runner_name and self.game.is_installed:
             for entry in self.get_runner_entries(self.game):
                 name, label, callback = entry
@@ -160,20 +178,24 @@ class GamePanel(GenericPanel):
         for action_id, button in self.buttons.items():
             position = None
             if action_id in ("play", "stop", "install"):
-                position = (play_x_offset,
-                            base_height)
+                position = (play_x_offset, base_height)
             if action_id == "configure":
-                position = (icon_start,
-                            base_height + icons_y_offset)
+                position = (icon_start, base_height + icons_y_offset)
             if action_id == "browse":
-                position = (icon_start + icon_offset + icon_width,
-                            base_height + icons_y_offset)
+                position = (
+                    icon_start + icon_offset + icon_width,
+                    base_height + icons_y_offset,
+                )
             if action_id == "show_logs":
-                position = (icon_start + icon_offset * 2 + icon_width * 2,
-                            base_height + icons_y_offset)
+                position = (
+                    icon_start + icon_offset * 2 + icon_width * 2,
+                    base_height + icons_y_offset,
+                )
             if action_id == "remove":
-                position = (icon_start + icon_offset * 3 + icon_width * 3,
-                            base_height + icons_y_offset)
+                position = (
+                    icon_start + icon_offset * 3 + icon_width * 3,
+                    base_height + icons_y_offset,
+                )
 
             current_y = base_height + 150
             if action_id == "execute-script":
@@ -188,11 +210,21 @@ class GamePanel(GenericPanel):
                 position = (buttons_x_offset, current_y + 160)
 
             if not position:
-                position = (buttons_x_offset, extra_button_start + extra_button_index * 40)
+                position = (
+                    buttons_x_offset,
+                    extra_button_start + extra_button_index * 40,
+                )
                 extra_button_index += 1
 
             self.put(button, position[0], position[1])
 
+    def on_shortcut_edited(self, widget, action_id):
+        self.buttons[action_id].hide()
+        if "rm" == action_id[0:2]:
+            self.buttons[action_id[3:]].show()
+        else:
+            self.buttons["rm-" + action_id].show()
+
     def on_game_start(self, widget):
         self.buttons["play"].set_label("Launching...")
         self.buttons["play"].set_sensitive(False)
@@ -202,13 +234,11 @@ class GamePanel(GenericPanel):
         self.buttons["play"].hide()
         self.buttons["play"].set_label("Play")
         self.buttons["play"].set_sensitive(True)
-        self.buttons["show_logs"].set_sensitive(True)
 
     def on_game_stop(self, widget, game_id=None):
         for child in self.get_children():
             child.destroy()
         self.place_content()
-        self.buttons["show_logs"].set_sensitive(True)
 
     def on_close(self, _widget):
         self.emit("panel-closed")
