@@ -12,11 +12,12 @@ from lutris.runners.runner import Runner
 from lutris.util.jobs import thread_safe_call
 from lutris.util import display, system
 from lutris.util.log import logger
-from lutris.util.strings import parse_version
+from lutris.util.strings import parse_version, split_arguments
 from lutris.util.graphics.vkquery import is_vulkan_supported
 from lutris.util.wine.prefix import WinePrefixManager
 from lutris.util.wine.x360ce import X360ce
 from lutris.util.wine import dxvk
+from lutris.util.wine import nine
 from lutris.util.wine.wine import (
     POL_PATH,
     WINE_DIR,
@@ -66,7 +67,8 @@ class wine(Runner):
             "option": "args",
             "type": "string",
             "label": "Arguments",
-            "help": "Windows command line arguments used when launching the game"
+            "help": "Windows command line arguments used when launching the game",
+            "validator": shlex.split
         },
         {
             "option": "working_dir",
@@ -94,7 +96,7 @@ class wine(Runner):
             "label": "Prefix architecture",
             "choices": [("Auto", "auto"), ("32-bit", "win32"), ("64-bit", "win64")],
             "default": "auto",
-            "help": "The architecture of the Windows environment"
+            "help": "The architecture of the Windows environment",
         },
     ]
 
@@ -143,15 +145,21 @@ class wine(Runner):
                 version_choices.append((label, version))
             return version_choices
 
-        def get_dxvk_choices():
+        def dxvk_choices(manager_class):
             version_choices = [
                 ("Manual", "manual"),
-                (dxvk.DXVK_LATEST, dxvk.DXVK_LATEST),
+                (manager_class.DXVK_LATEST, manager_class.DXVK_LATEST),
             ]
-            for version in dxvk.DXVK_PAST_RELEASES:
+            for version in manager_class.DXVK_PAST_RELEASES:
                 version_choices.append((version, version))
             return version_choices
 
+        def get_dxvk_choices():
+            return dxvk_choices(dxvk.DXVKManager)
+
+        def get_d9vk_choices():
+            return dxvk_choices(dxvk.D9VKManager)
+
         def esync_limit_callback(widget, option, config):
             limits_set = is_esync_limit_set()
             wine_path = self.get_path_for_version(config["version"])
@@ -201,10 +209,14 @@ class wine(Runner):
                 "option": "dxvk",
                 "label": "Enable DXVK",
                 "type": "extended_bool",
-                "help": "Use DXVK to translate DirectX 11 calls to Vulkan",
                 "callback": dxvk_vulkan_callback,
                 "callback_on": True,
                 "active": True,
+                "help": (
+                    "Use DXVK to increase compatibility and performance "
+                    "in Direct3D 11 and 10 applications by translating "
+                    "their calls to Vulkan."
+                ),
             },
             {
                 "option": "dxvk_version",
@@ -212,16 +224,54 @@ class wine(Runner):
                 "advanced": True,
                 "type": "choice_with_entry",
                 "choices": get_dxvk_choices,
-                "default": dxvk.DXVK_LATEST,
+                "default": dxvk.DXVKManager.DXVK_LATEST,
+            },
+            {
+                "option": "d9vk",
+                "label": "Enable D9VK",
+                "type": "extended_bool",
+                "callback": dxvk_vulkan_callback,
+                "callback_on": True,
+                "active": True,
+                "help": (
+                    "Use D9VK to increase performance in Direct3D 9 "
+                    "applications by translating their calls to Vulkan."
+                ),
+            },
+            {
+                "option": "d9vk_version",
+                "label": "D9VK version",
+                "advanced": True,
+                "type": "choice_with_entry",
+                "choices": get_d9vk_choices,
+                "default": dxvk.D9VKManager.DXVK_LATEST,
             },
             {
                 "option": "esync",
                 "label": "Enable Esync",
                 "type": "extended_bool",
-                "help": "Enable eventfd-based synchronization (esync)",
                 "callback": esync_limit_callback,
                 "callback_on": True,
                 "active": True,
+                "help": (
+                    "Enable eventfd-based synchronization (esync). "
+                    "This will increase performance in applications "
+                    "that take advantage of multi-core processors."
+                ),
+            },
+            {
+                "option": "gallium_nine",
+                "label": "Enable Gallium Nine",
+                "type": "bool",
+                "default": False,
+                "condition": nine.NineManager.is_available(),
+                "advanced": True,
+                "help": (
+                    "Gallium Nine allows to run Direct3D 9 applications faster.\n"
+                    "Make sure your active graphics card supports Gallium Nine state "
+                    "tracker before enabling this option.\n"
+                    "Note: This feature is not supported by proprietary Nvidia driver."
+                ),
             },
             {
                 "option": "x360ce-path",
@@ -351,13 +401,14 @@ class wine(Runner):
                 "label": "Anti-aliasing Sample Count",
                 "type": "choice",
                 "choices": [
-                    ("0", "0 (disabled)"),
+                    ("Auto", "auto"),
+                    ("0", "0"),
                     ("2", "2"),
                     ("4", "4"),
                     ("8", "8"),
-                    ("16", "16")
+                    ("16", "16"),
                 ],
-                "default": "0",
+                "default": "auto",
                 "advanced": True,
                 "help": (
                     "Override swapchain sample count. It can be used to force enable multisampling "
@@ -365,7 +416,7 @@ class wine(Runner):
                     "panel setting available with some GPU drivers. This one might work in more "
                     "cases than the driver setting though. "
                     "Not all applications are compatible with all sample counts. "
-                )
+                ),
             },
             {
                 "option": "UseXVidMode",
@@ -460,12 +511,11 @@ class wine(Runner):
     @property
     def context_menu_entries(self):
         """Return the contexual menu entries for wine"""
-        menu_entries = [
-            ("wineexec", "Run EXE inside wine prefix", self.run_wineexec)
-        ]
+        menu_entries = [("wineexec", "Run EXE inside wine prefix", self.run_wineexec)]
         if "Proton" not in self.get_version():
             menu_entries.append(("winecfg", "Wine configuration", self.run_winecfg))
         menu_entries += [
+            ("wineconsole", "Wine console", self.run_wineconsole),
             ("wine-regedit", "Wine registry", self.run_regedit),
             ("winekill", "Kill all wine processes", self.run_winekill),
             ("winetricks", "Winetricks", self.run_winetricks),
@@ -478,8 +528,10 @@ class wine(Runner):
         """Return the absolute path of the Wine prefix"""
         _prefix_path = self.game_config.get("prefix")
         if not _prefix_path:
-            logger.warning("Wine prefix not provided, defaulting to $WINEPREFIX then ~/.wine."
-                           " This is probably not the intended behavior.")
+            logger.warning(
+                "Wine prefix not provided, defaulting to $WINEPREFIX then ~/.wine."
+                " This is probably not the intended behavior."
+            )
             _prefix_path = os.environ.get("WINEPREFIX") or "~/.wine"
         return os.path.expanduser(_prefix_path)
 
@@ -488,7 +540,7 @@ class wine(Runner):
         """Return the game's executable's path."""
         exe = self.game_config.get("exe")
         if not exe:
-            logger.warning("The game doesn't have an executabe")
+            logger.warning("The game doesn't have an executable")
             return
         if exe and os.path.isabs(exe):
             return exe
@@ -564,9 +616,9 @@ class wine(Runner):
                 # Update the version in the config
                 if version == self.runner_config.get("version"):
                     self.runner_config["version"] = default_version
-                    # TODO: runner_config is a dict so we have to instanciate a
+                    # TODO: runner_config is a dict so we have to instanciate a #  pylint: disable=fixme
                     # LutrisConfig object to save it.
-                    # XXX: The version key could be either in the game specific
+                    # XXX: The version key could be either in the game specific #  pylint: disable=fixme
                     # config or the runner specific config. We need to know
                     # which one to get the correct LutrisConfig object.
             return wine_path
@@ -575,27 +627,28 @@ class wine(Runner):
         """Check if Wine is installed.
         If no version is passed, checks if any version of wine is available
         """
-        if not version:
-            wine_versions = get_wine_versions()
-            if min_version:
-                min_version_list, _, _ = parse_version(min_version)
-                for version in wine_versions:
-                    version_list, _, _ = parse_version(version)
-                    if version_list > min_version_list:
-                        return True
-                logger.warning("Wine %s or higher not found", min_version)
-            return bool(wine_versions)
-        return system.path_exists(self.get_executable(version, fallback))
+        if version:
+            return system.path_exists(self.get_executable(version, fallback))
+
+        wine_versions = get_wine_versions()
+        if min_version:
+            min_version_list, _, _ = parse_version(min_version)
+            for wine_version in wine_versions:
+                version_list, _, _ = parse_version(wine_version)
+                if version_list > min_version_list:
+                    return True
+            logger.warning("Wine %s or higher not found", min_version)
+        return bool(wine_versions)
 
     @classmethod
     def msi_exec(
-            cls,
-            msi_file,
-            quiet=False,
-            prefix=None,
-            wine_path=None,
-            working_dir=None,
-            blocking=False,
+        cls,
+        msi_file,
+        quiet=False,
+        prefix=None,
+        wine_path=None,
+        working_dir=None,
+        blocking=False,
     ):
         msi_args = "/i %s" % msi_file
         if quiet:
@@ -609,20 +662,31 @@ class wine(Runner):
             blocking=blocking,
         )
 
+    def _run_executable(self, executable):
+        """Runs a Windows executable using this game's configuration"""
+        wineexec(
+            executable,
+            wine_path=self.get_executable(),
+            prefix=self.prefix_path,
+            config=self,
+            env=self.get_env(os_env=True),
+        )
+
     def run_wineexec(self, *args):
+        """Ask the user for an arbitrary exe file to run in the game's prefix"""
         dlg = FileDialog("Select an EXE or MSI file", default_path=self.game_path)
         filename = dlg.filename
         if not filename:
             return
         self.prelaunch()
-        wineexec(
-            filename,
-            wine_path=self.get_executable(),
-            prefix=self.prefix_path,
-            config=self,
-        )
+        self._run_executable(filename)
+
+    def run_wineconsole(self, *args):
+        """Runs wineconsole inside wine prefix."""
+        self._run_executable("wineconsole")
 
     def run_winecfg(self, *args):
+        """Run winecfg in the current context"""
         self.prelaunch()
         winecfg(
             wine_path=self.get_executable(),
@@ -632,15 +696,12 @@ class wine(Runner):
         )
 
     def run_regedit(self, *args):
+        """Run regedit in the current context"""
         self.prelaunch()
-        wineexec(
-            "regedit",
-            wine_path=self.get_executable(),
-            prefix=self.prefix_path,
-            config=self,
-        )
+        self._run_executable("regedit")
 
     def run_winetricks(self, *args):
+        """Run winetricks in the current context"""
         self.prelaunch()
         winetricks(
             "", prefix=self.prefix_path, wine_path=self.get_executable(), config=self
@@ -649,11 +710,7 @@ class wine(Runner):
     def run_winecpl(self, *args):
         """Execute Wine control panel."""
         self.prelaunch()
-        wineexec(
-            "control",
-            prefix=self.prefix_path,
-            wine_path=self.get_executable()
-        )
+        self._run_executable("control")
 
     def run_winekill(self, *args):
         """Runs wineserver -k."""
@@ -681,7 +738,7 @@ class wine(Runner):
         for key, path in self.reg_keys.items():
             value = self.runner_config.get(key) or "auto"
             if not value or value == "auto" and key not in managed_keys.keys():
-                prefix_manager.clear_registry_key(path)
+                prefix_manager.clear_registry_subkeys(path, key)
             elif key in self.runner_config:
                 if key in managed_keys.keys():
                     # Do not pass fallback 'auto' value to managed keys
@@ -695,11 +752,7 @@ class wine(Runner):
 
                 prefix_manager.set_registry_key(path, key, value)
 
-    def toggle_dxvk(self, enable, version=None):
-        dxvk_manager = dxvk.DXVKManager(
-            self.prefix_path, arch=self.wine_arch, version=version
-        )
-
+    def toggle_dxvk(self, enable, version=None, dxvk_manager: dxvk.DXVKManager = None):
         # manual version only sets the dlls to native
         if version.lower() != "manual":
             if enable:
@@ -715,6 +768,20 @@ class wine(Runner):
                 if dxvk_manager.dxvk_dll_exists(dll):
                     self.dll_overrides[dll] = "n"
 
+    def setup_dxvk(self, base_name, dxvk_manager: dxvk.DXVKManager = None):
+        if not dxvk_manager:
+            return
+        try:
+            self.toggle_dxvk(
+                bool(self.runner_config.get(base_name)),
+                version=dxvk_manager.version,
+                dxvk_manager=dxvk_manager,
+            )
+        except dxvk.UnavailableDXVKVersion:
+            raise GameConfigError(
+                "Unable to get " + base_name.upper() + " %s" % dxvk_manager.version
+            )
+
     def prelaunch(self):
         if not system.path_exists(os.path.join(self.prefix_path, "user.reg")):
             create_prefix(self.prefix_path, arch=self.wine_arch)
@@ -724,20 +791,35 @@ class wine(Runner):
         self.sandbox(prefix_manager)
         self.set_regedit_keys()
         self.setup_x360ce(self.runner_config.get("x360ce-path"))
-        try:
-            dxvk_version = self.runner_config.get("dxvk_version")
-            self.toggle_dxvk(
-                bool(self.runner_config.get("dxvk")),
-                version=dxvk_version,
+        self.setup_dxvk(
+            "dxvk",
+            dxvk_manager=dxvk.DXVKManager(
+                self.prefix_path,
+                arch=self.wine_arch,
+                version=self.runner_config.get("dxvk_version"),
+            ),
+        )
+
+        # we don't want d9vk to restore d3d9.dll, because dxvk could set it already
+        if bool(self.runner_config.get("d9vk")):
+            self.setup_dxvk(
+                "d9vk",
+                dxvk_manager=dxvk.D9VKManager(
+                    self.prefix_path,
+                    arch=self.wine_arch,
+                    version=self.runner_config.get("d9vk_version"),
+                ),
             )
-        except dxvk.UnavailableDXVKVersion:
-            raise GameConfigError("Unable to get DXVK %s" % dxvk_version)
+        try:
+            self.setup_nine(self.runner_config.get("gallium_nine"))
+        except nine.NineUnavailable as ex:
+            raise GameConfigError("Unable to configure GalliumNine: %s" % ex)
         return True
 
     def get_dll_overrides(self):
         """Return the DLLs overriden at runtime"""
         try:
-            overrides = self.runner_config['overrides']
+            overrides = self.runner_config["overrides"]
         except KeyError:
             overrides = {}
         else:
@@ -790,7 +872,7 @@ class wine(Runner):
         return runtime.get_env(
             version=version,
             prefer_system_libs=self.system_config.get("prefer_system_libs", True),
-            wine_path=wine_root
+            wine_path=wine_root,
         )
 
     def get_pids(self, wine_path=None):
@@ -850,18 +932,31 @@ class wine(Runner):
         if self.runner_config.get("x360ce-dinput"):
             self.dll_overrides["dinput8"] = "native"
 
+    def setup_nine(self, enable):
+        nine_manager = nine.NineManager(self.prefix_path, self.wine_arch,)
+
+        if enable:
+            nine_manager.enable()
+        else:
+            nine_manager.disable()
+
     def sandbox(self, wine_prefix):
         if self.runner_config.get("sandbox", True):
             wine_prefix.desktop_integration(
                 desktop_dir=self.runner_config.get("sandbox_dir")
             )
+        else:
+            wine_prefix.desktop_integration(restore=True)
 
     def play(self):
         game_exe = self.game_exe
         arguments = self.game_config.get("args", "")
-        using_dxvk = self.runner_config.get("dxvk")
+        launch_info = {"env": self.get_env(os_env=False)}
+        using_dxvk = self.runner_config.get("dxvk") or self.runner_config.get("d9vk")
 
         if using_dxvk:
+            # Set this to 1 to enable access to more RAM for 32bit applications
+            launch_info["env"]["WINE_LARGE_ADDRESS_AWARE"] = "1"
             if not is_vulkan_supported():
                 if not display_vulkan_error(True):
                     return {"error": "VULKAN_NOT_FOUND"}
@@ -869,8 +964,6 @@ class wine(Runner):
         if not system.path_exists(game_exe):
             return {"error": "FILE_NOT_FOUND", "file": game_exe}
 
-        launch_info = {"env": self.get_env(os_env=False)}
-
         if launch_info["env"].get("WINEESYNC") == "1":
             limit_set = is_esync_limit_set()
             wine_ver = is_version_esync(self.get_executable())
@@ -894,7 +987,7 @@ class wine(Runner):
             command = command + args
 
         if arguments:
-            for arg in shlex.split(arguments):
+            for arg in split_arguments(arguments):
                 command.append(arg)
         launch_info["command"] = command
         return launch_info
