@@ -1,3 +1,4 @@
+"""Manipulate Wine registry files"""
 import os
 import re
 from collections import OrderedDict
@@ -100,7 +101,7 @@ class WineRegistry:
             except Exception:  # pylint: disable=broad-except
                 logger.exception(
                     "Failed to registry read %s, please send attach this file in a bug report",
-                    reg_filename
+                    reg_filename,
                 )
                 registry_content = []
         return registry_content
@@ -121,7 +122,7 @@ class WineRegistry:
                     additional_values.append(line)
                 elif not add_next_to_value:
                     if additional_values:
-                        additional_values = '\n'.join(additional_values)
+                        additional_values = "\n".join(additional_values)
                         current_key.add_to_last(additional_values)
                         additional_values = []
                     current_key.parse(line)
@@ -150,9 +151,10 @@ class WineRegistry:
             raise OSError("No filename provided")
         prefix_path = os.path.dirname(path)
         if not os.path.isdir(prefix_path):
-            raise OSError("Invalid Wine prefix path %s, make sure to "
-                          "create the prefix before saving to a registry"
-                          % prefix_path)
+            raise OSError(
+                "Invalid Wine prefix path %s, make sure to "
+                "create the prefix before saving to a registry" % prefix_path
+            )
         with open(path, "w") as registry_file:
             registry_file.write(self.render())
 
@@ -186,7 +188,7 @@ class WineRegistry:
             key.subkeys.pop(subkey)
 
     def get_unix_path(self, windows_path):
-        windows_path = windows_path.replace("\\\\", "/")
+        windows_path = windows_path.replace("\\", "/")
         if not self.prefix_path:
             return
         drives_path = os.path.join(self.prefix_path, "dosdevices")
@@ -260,7 +262,11 @@ class WineRegistryKey:
             self.subkeys["default"] = value
 
     def add_to_last(self, line):
-        last_subkey = next(reversed(self.subkeys))
+        try:
+            last_subkey = next(reversed(self.subkeys))
+        except StopIteration:
+            logger.warning("Should this be happening?")
+            return
         self.subkeys[last_subkey] += "\n{}".format(line)
 
     def render(self):
@@ -286,6 +292,26 @@ class WineRegistryKey:
             return '"{}"'.format(value)
         raise NotImplementedError("TODO")
 
+    def decode_unicode(self, string):
+        chunks = string.split("\\x")
+        out = chunks.pop(0).encode().decode("unicode_escape")
+        for chunk in chunks:
+            # We have seen file with unicode characters escaped on 1 byte (\xfa),
+            # 1.5 bytes (\x444) and 2 bytes (\x00ed). So we try 0 padding, 1 and 2
+            # (python wants its escaped sequence to be exactly on 4 characters).
+            # The exception let us know if it worked or not
+            for i in [0, 1, 2]:
+                try:
+                    out += (
+                        "\\u{}{}".format("0" * i, chunk)
+                        .encode()
+                        .decode("unicode_escape")
+                    )
+                    break
+                except UnicodeDecodeError:
+                    pass
+        return out
+
     def add_meta(self, meta_line):
         if not meta_line.startswith("#"):
             raise ValueError("Key metas should start with '#'")
@@ -312,7 +338,7 @@ class WineRegistryKey:
             return None
         value = self.subkeys[name]
         if value.startswith('"') and value.endswith('"'):
-            return value[1:-1]
+            return self.decode_unicode(value[1:-1])
         if value.startswith("dword:"):
             return int(value[6:], 16)
         raise ValueError("Handle %s" % value)
